# ncurses 5.8 - patch 20110329 - Thomas E. Dickey
#
# ------------------------------------------------------------------------------
#
# Ncurses 5.8 is at
# 	ftp.gnu.org:/pub/gnu
#
# Patches for ncurses 5.8 are in the subdirectory
# 	ftp://invisible-island.net/ncurses/5.8
#
# ------------------------------------------------------------------------------
# ftp://invisible-island.net/ncurses/5.8/ncurses-5.8-20110329.patch.gz
# patch by Thomas E. Dickey <dickey@invisible-island.net>
# created  Tue Mar 29 10:57:44 UTC 2011
# ------------------------------------------------------------------------------
# Ada95/aclocal.m4                                |   63 ++++++-
# Ada95/configure                                 |  144 ++++++++++++------
# Ada95/configure.in                              |    7 
# Ada95/samples/Makefile.in                       |    6 
# Ada95/src/Makefile.in                           |    7 
# NEWS                                            |   13 +
# TO-DO                                           |   20 --
# aclocal.m4                                      |   49 ++++++
# configure                                       |  176 ++++++++++++++--------
# configure.in                                    |    5 
# dist.mk                                         |    4 
# ncurses-5.8-20110329/Ada95/src/ncurses_compat.c |  135 ++++++++++++++++
# 12 files changed, 486 insertions(+), 143 deletions(-)
# ------------------------------------------------------------------------------
Index: Ada95/aclocal.m4
Prereq:  1.22 
--- ncurses-5.8-20110326+/Ada95/aclocal.m4	2011-03-24 00:31:33.000000000 +0000
+++ ncurses-5.8-20110329/Ada95/aclocal.m4	2011-03-28 00:08:52.000000000 +0000
@@ -28,7 +28,7 @@
 dnl
 dnl Author: Thomas E. Dickey
 dnl
-dnl $Id: aclocal.m4,v 1.22 2011/03/24 00:31:33 tom Exp $
+dnl $Id: aclocal.m4,v 1.23 2011/03/28 00:08:52 tom Exp $
 dnl Macros used in NCURSES Ada95 auto-configuration script.
 dnl
 dnl These macros are maintained separately from NCURSES.  The copyright on
@@ -1070,6 +1070,53 @@
 AC_SUBST(cf_generic_objects)
 ])dnl
 dnl ---------------------------------------------------------------------------
+dnl CF_GNAT_SIGINT version: 1 updated: 2011/03/27 20:07:59
+dnl --------------
+dnl Check if gnat supports SIGINT, and presumably tasking.  For the latter, it
+dnl is noted that gnat may compile a tasking unit even for configurations which
+dnl fail at runtime.
+AC_DEFUN([CF_GNAT_SIGINT],[
+AC_CACHE_CHECK(if GNAT supports SIGINT,cf_cv_gnat_sigint,[
+CF_GNAT_TRY_LINK([with Ada.Interrupts.Names;
+
+package ConfTest is
+
+   pragma Warnings (Off);  --  the next pragma exists since 3.11p
+   pragma Unreserve_All_Interrupts;
+   pragma Warnings (On);
+
+   protected Process is
+      procedure Stop;
+      function Continue return Boolean;
+      pragma Attach_Handler (Stop, Ada.Interrupts.Names.SIGINT);
+   private
+      Done : Boolean := False;
+   end Process;
+
+end ConfTest;],
+[package body ConfTest is
+   protected body Process is
+      procedure Stop is
+      begin
+         Done := True;
+      end Stop;
+      function Continue return Boolean is
+      begin
+         return not Done;
+      end Continue;
+   end Process;
+end ConfTest;],
+	[cf_cv_gnat_sigint=yes],
+	[cf_cv_gnat_sigint=no])])
+
+if test $cf_cv_gnat_sigint = yes ; then
+	USE_GNAT_SIGINT=""
+else
+	USE_GNAT_SIGINT="#"
+fi
+AC_SUBST(USE_GNAT_SIGINT)
+])dnl
+dnl ---------------------------------------------------------------------------
 dnl CF_GNAT_PRAGMA_UNREF version: 1 updated: 2010/06/19 15:22:18
 dnl --------------------
 dnl Check if the gnat pragma "Unreferenced" works.
@@ -1985,7 +2032,7 @@
 echo "${as_me:-configure}:__oline__: testing $* ..." 1>&AC_FD_CC
 ])dnl
 dnl ---------------------------------------------------------------------------
-dnl CF_NCURSES_ADDON version: 3 updated: 2010/10/23 15:54:49
+dnl CF_NCURSES_ADDON version: 4 updated: 2011/03/27 17:10:13
 dnl ----------------
 dnl Configure an ncurses add-on, built outside the ncurses tree.
 AC_DEFUN([CF_NCURSES_ADDON],[
@@ -2010,8 +2057,8 @@
 cf_version=`$NCURSES_CONFIG --version`
 
 NCURSES_MAJOR=`echo "$cf_version" | sed -e 's/\..*//'`
-NCURSES_MINOR=`echo "$cf_version" | sed -e 's/^[[0-9]]\+\.//' -e 's/\..*//'`
-NCURSES_PATCH=`echo "$cf_version" | sed -e 's/^[[0-9]]\+\.[[0-9]]\+\.//'`
+NCURSES_MINOR=`echo "$cf_version" | sed -e 's/^[[0-9]][[0-9]]*\.//' -e 's/\..*//'`
+NCURSES_PATCH=`echo "$cf_version" | sed -e 's/^[[0-9]][[0-9]]*\.[[0-9]][[0-9]]*\.//'`
 
 # ABI version is not available from headers
 cf_cv_abi_version=`$NCURSES_CONFIG --abi-version`
@@ -2027,10 +2074,10 @@
 	cf_try="$ac_cpp conftest.$ac_ext 2>&5 | fgrep AUTOCONF_$cf_name >conftest.out"
 	AC_TRY_EVAL(cf_try)
 	if test -f conftest.out ; then
-		cf_result=`cat conftest.out | sed -e "s/^.*AUTOCONF_$cf_name[[ 	]]\+//"`
-		eval NCURSES_$cf_name=$cf_result
-		cat conftest.$ac_ext
-		cat conftest.out
+		cf_result=`cat conftest.out | sed -e "s/^.*AUTOCONF_$cf_name[[ 	]][[ 	]]*//"`
+		eval NCURSES_$cf_name=\"$cf_result\"
+		# cat conftest.$ac_ext
+		# cat conftest.out
 	fi
 done
 
Index: Ada95/configure
--- ncurses-5.8-20110326+/Ada95/configure	2011-03-26 23:56:09.000000000 +0000
+++ ncurses-5.8-20110329/Ada95/configure	2011-03-28 00:15:03.000000000 +0000
@@ -1,5 +1,5 @@
 #! /bin/sh
-# From configure.in Revision: 1.26 .
+# From configure.in Revision: 1.27 .
 # Guess values for system-dependent variables and create Makefiles.
 # Generated by Autoconf 2.52.20101002.
 #
@@ -2833,7 +2833,7 @@
 
 fi
 
-if test "$PKG_CONFIG" != no ; then
+if test "$PKG_CONFIG" != none ; then
 	echo "$as_me:2837: checking if we should install .pc files for $PKG_CONFIG" >&5
 echo $ECHO_N "checking if we should install .pc files for $PKG_CONFIG... $ECHO_C" >&6
 
@@ -7178,8 +7178,8 @@
 cf_version=`$NCURSES_CONFIG --version`
 
 NCURSES_MAJOR=`echo "$cf_version" | sed -e 's/\..*//'`
-NCURSES_MINOR=`echo "$cf_version" | sed -e 's/^[0-9]\+\.//' -e 's/\..*//'`
-NCURSES_PATCH=`echo "$cf_version" | sed -e 's/^[0-9]\+\.[0-9]\+\.//'`
+NCURSES_MINOR=`echo "$cf_version" | sed -e 's/^[0-9][0-9]*\.//' -e 's/\..*//'`
+NCURSES_PATCH=`echo "$cf_version" | sed -e 's/^[0-9][0-9]*\.[0-9][0-9]*\.//'`
 
 # ABI version is not available from headers
 cf_cv_abi_version=`$NCURSES_CONFIG --abi-version`
@@ -7199,10 +7199,10 @@
   echo "$as_me:7199: \$? = $ac_status" >&5
   (exit $ac_status); }
 	if test -f conftest.out ; then
-		cf_result=`cat conftest.out | sed -e "s/^.*AUTOCONF_$cf_name[ 	]\+//"`
-		eval NCURSES_$cf_name=$cf_result
-		cat conftest.$ac_ext
-		cat conftest.out
+		cf_result=`cat conftest.out | sed -e "s/^.*AUTOCONF_$cf_name[ 	][ 	]*//"`
+		eval NCURSES_$cf_name=\"$cf_result\"
+		# cat conftest.$ac_ext
+		# cat conftest.out
 	fi
 done
 
@@ -10930,7 +10930,64 @@
 	cf_generic_objects=
 fi
 
-echo "$as_me:10933: checking if GNAT pragma Unreferenced works" >&5
+echo "$as_me:10933: checking if GNAT supports SIGINT" >&5
+echo $ECHO_N "checking if GNAT supports SIGINT... $ECHO_C" >&6
+if test "${cf_cv_gnat_sigint+set}" = set; then
+  echo $ECHO_N "(cached) $ECHO_C" >&6
+else
+
+rm -rf conftest* *~conftest*
+cat >>conftest.ads <<CF_EOF
+with Ada.Interrupts.Names;
+
+package ConfTest is
+
+   pragma Warnings (Off);  --  the next pragma exists since 3.11p
+   pragma Unreserve_All_Interrupts;
+   pragma Warnings (On);
+
+   protected Process is
+      procedure Stop;
+      function Continue return Boolean;
+      pragma Attach_Handler (Stop, Ada.Interrupts.Names.SIGINT);
+   private
+      Done : Boolean := False;
+   end Process;
+
+end ConfTest;
+CF_EOF
+cat >>conftest.adb <<CF_EOF
+package body ConfTest is
+   protected body Process is
+      procedure Stop is
+      begin
+         Done := True;
+      end Stop;
+      function Continue return Boolean is
+      begin
+         return not Done;
+      end Continue;
+   end Process;
+end ConfTest;
+CF_EOF
+if ( $cf_ada_make $ADAFLAGS conftest 1>&5 2>&1 ) ; then
+      cf_cv_gnat_sigint=yes
+else
+   cf_cv_gnat_sigint=no
+fi
+rm -rf conftest* *~conftest*
+
+fi
+echo "$as_me:10981: result: $cf_cv_gnat_sigint" >&5
+echo "${ECHO_T}$cf_cv_gnat_sigint" >&6
+
+if test $cf_cv_gnat_sigint = yes ; then
+	USE_GNAT_SIGINT=""
+else
+	USE_GNAT_SIGINT="#"
+fi
+
+echo "$as_me:10990: checking if GNAT pragma Unreferenced works" >&5
 echo $ECHO_N "checking if GNAT pragma Unreferenced works... $ECHO_C" >&6
 if test "${cf_cv_pragma_unreferenced+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -10961,7 +11018,7 @@
 rm -rf conftest* *~conftest*
 
 fi
-echo "$as_me:10964: result: $cf_cv_pragma_unreferenced" >&5
+echo "$as_me:11021: result: $cf_cv_pragma_unreferenced" >&5
 echo "${ECHO_T}$cf_cv_pragma_unreferenced" >&6
 
 # if the pragma is supported, use it (needed in the Trace code).
@@ -10974,7 +11031,7 @@
 cf_gnat_libraries=no
 cf_gnat_projects=no
 
-echo "$as_me:10977: checking if GNAT supports project files" >&5
+echo "$as_me:11034: checking if GNAT supports project files" >&5
 echo $ECHO_N "checking if GNAT supports project files... $ECHO_C" >&6
 case $cf_gnat_version in #(vi
 3.[0-9]*) #(vi
@@ -11042,14 +11099,14 @@
 	esac
 	;;
 esac
-echo "$as_me:11045: result: $cf_gnat_projects" >&5
+echo "$as_me:11102: result: $cf_gnat_projects" >&5
 echo "${ECHO_T}$cf_gnat_projects" >&6
 
 if test $cf_gnat_projects = yes
 then
-	echo "$as_me:11050: checking if GNAT supports libraries" >&5
+	echo "$as_me:11107: checking if GNAT supports libraries" >&5
 echo $ECHO_N "checking if GNAT supports libraries... $ECHO_C" >&6
-	echo "$as_me:11052: result: $cf_gnat_libraries" >&5
+	echo "$as_me:11109: result: $cf_gnat_libraries" >&5
 echo "${ECHO_T}$cf_gnat_libraries" >&6
 fi
 
@@ -11069,7 +11126,7 @@
 	USE_GNAT_LIBRARIES="#"
 fi
 
-echo "$as_me:11072: checking for ada-compiler" >&5
+echo "$as_me:11129: checking for ada-compiler" >&5
 echo $ECHO_N "checking for ada-compiler... $ECHO_C" >&6
 
 # Check whether --with-ada-compiler or --without-ada-compiler was given.
@@ -11080,12 +11137,12 @@
   cf_ada_compiler=gnatmake
 fi;
 
-echo "$as_me:11083: result: $cf_ada_compiler" >&5
+echo "$as_me:11140: result: $cf_ada_compiler" >&5
 echo "${ECHO_T}$cf_ada_compiler" >&6
 
 		cf_ada_package=terminal_interface
 
-echo "$as_me:11088: checking for ada-include" >&5
+echo "$as_me:11145: checking for ada-include" >&5
 echo $ECHO_N "checking for ada-include... $ECHO_C" >&6
 
 # Check whether --with-ada-include or --without-ada-include was given.
@@ -11121,7 +11178,7 @@
   withval=`echo $withval | sed -e s%NONE%$cf_path_syntax%`
   ;;
 *)
-  { { echo "$as_me:11124: error: expected a pathname, not \"$withval\"" >&5
+  { { echo "$as_me:11181: error: expected a pathname, not \"$withval\"" >&5
 echo "$as_me: error: expected a pathname, not \"$withval\"" >&2;}
    { (exit 1); exit 1; }; }
   ;;
@@ -11130,10 +11187,10 @@
 fi
 ADA_INCLUDE="$withval"
 
-echo "$as_me:11133: result: $ADA_INCLUDE" >&5
+echo "$as_me:11190: result: $ADA_INCLUDE" >&5
 echo "${ECHO_T}$ADA_INCLUDE" >&6
 
-echo "$as_me:11136: checking for ada-objects" >&5
+echo "$as_me:11193: checking for ada-objects" >&5
 echo $ECHO_N "checking for ada-objects... $ECHO_C" >&6
 
 # Check whether --with-ada-objects or --without-ada-objects was given.
@@ -11169,7 +11226,7 @@
   withval=`echo $withval | sed -e s%NONE%$cf_path_syntax%`
   ;;
 *)
-  { { echo "$as_me:11172: error: expected a pathname, not \"$withval\"" >&5
+  { { echo "$as_me:11229: error: expected a pathname, not \"$withval\"" >&5
 echo "$as_me: error: expected a pathname, not \"$withval\"" >&2;}
    { (exit 1); exit 1; }; }
   ;;
@@ -11178,10 +11235,10 @@
 fi
 ADA_OBJECTS="$withval"
 
-echo "$as_me:11181: result: $ADA_OBJECTS" >&5
+echo "$as_me:11238: result: $ADA_OBJECTS" >&5
 echo "${ECHO_T}$ADA_OBJECTS" >&6
 
-echo "$as_me:11184: checking if an Ada95 shared-library should be built" >&5
+echo "$as_me:11241: checking if an Ada95 shared-library should be built" >&5
 echo $ECHO_N "checking if an Ada95 shared-library should be built... $ECHO_C" >&6
 
 # Check whether --with-ada-sharedlib or --without-ada-sharedlib was given.
@@ -11191,7 +11248,7 @@
 else
   with_ada_sharedlib=no
 fi;
-echo "$as_me:11194: result: $with_ada_sharedlib" >&5
+echo "$as_me:11251: result: $with_ada_sharedlib" >&5
 echo "${ECHO_T}$with_ada_sharedlib" >&6
 
 ADA_SHAREDLIB='lib$(LIB_NAME).so.1'
@@ -11207,12 +11264,12 @@
 fi
 
 	else
-		{ { echo "$as_me:11210: error: No usable Ada compiler found" >&5
+		{ { echo "$as_me:11267: error: No usable Ada compiler found" >&5
 echo "$as_me: error: No usable Ada compiler found" >&2;}
    { (exit 1); exit 1; }; }
 	fi
 else
-	{ { echo "$as_me:11215: error: The Ada compiler is needed for this package" >&5
+	{ { echo "$as_me:11272: error: The Ada compiler is needed for this package" >&5
 echo "$as_me: error: The Ada compiler is needed for this package" >&2;}
    { (exit 1); exit 1; }; }
 fi
@@ -11257,7 +11314,7 @@
 fi
 
 ### Build up pieces for makefile rules
-echo "$as_me:11260: checking default library suffix" >&5
+echo "$as_me:11317: checking default library suffix" >&5
 echo $ECHO_N "checking default library suffix... $ECHO_C" >&6
 
 	case $DFT_LWR_MODEL in
@@ -11268,10 +11325,10 @@
 	shared)  DFT_ARG_SUFFIX=''   ;;
 	esac
 	test -n "$LIB_SUFFIX" && DFT_ARG_SUFFIX="${LIB_SUFFIX}${DFT_ARG_SUFFIX}"
-echo "$as_me:11271: result: $DFT_ARG_SUFFIX" >&5
+echo "$as_me:11328: result: $DFT_ARG_SUFFIX" >&5
 echo "${ECHO_T}$DFT_ARG_SUFFIX" >&6
 
-echo "$as_me:11274: checking default library-dependency suffix" >&5
+echo "$as_me:11331: checking default library-dependency suffix" >&5
 echo $ECHO_N "checking default library-dependency suffix... $ECHO_C" >&6
 
 	case $DFT_LWR_MODEL in #(vi
@@ -11324,10 +11381,10 @@
 	esac
 	test -n "$LIB_SUFFIX" && DFT_LIB_SUFFIX="${LIB_SUFFIX}${DFT_LIB_SUFFIX}"
 	test -n "$LIB_SUFFIX" && DFT_DEP_SUFFIX="${LIB_SUFFIX}${DFT_DEP_SUFFIX}"
-echo "$as_me:11327: result: $DFT_DEP_SUFFIX" >&5
+echo "$as_me:11384: result: $DFT_DEP_SUFFIX" >&5
 echo "${ECHO_T}$DFT_DEP_SUFFIX" >&6
 
-echo "$as_me:11330: checking default object directory" >&5
+echo "$as_me:11387: checking default object directory" >&5
 echo $ECHO_N "checking default object directory... $ECHO_C" >&6
 
 	case $DFT_LWR_MODEL in
@@ -11343,7 +11400,7 @@
 			DFT_OBJ_SUBDIR='obj_s' ;;
 		esac
 	esac
-echo "$as_me:11346: result: $DFT_OBJ_SUBDIR" >&5
+echo "$as_me:11403: result: $DFT_OBJ_SUBDIR" >&5
 echo "${ECHO_T}$DFT_OBJ_SUBDIR" >&6
 
 ### Set up low-level terminfo dependencies for makefiles.
@@ -11559,7 +11616,7 @@
 : ${CONFIG_STATUS=./config.status}
 ac_clean_files_save=$ac_clean_files
 ac_clean_files="$ac_clean_files $CONFIG_STATUS"
-{ echo "$as_me:11562: creating $CONFIG_STATUS" >&5
+{ echo "$as_me:11619: creating $CONFIG_STATUS" >&5
 echo "$as_me: creating $CONFIG_STATUS" >&6;}
 cat >$CONFIG_STATUS <<_ACEOF
 #! $SHELL
@@ -11735,7 +11792,7 @@
     echo "$ac_cs_version"; exit 0 ;;
   --he | --h)
     # Conflict between --help and --header
-    { { echo "$as_me:11738: error: ambiguous option: $1
+    { { echo "$as_me:11795: error: ambiguous option: $1
 Try \`$0 --help' for more information." >&5
 echo "$as_me: error: ambiguous option: $1
 Try \`$0 --help' for more information." >&2;}
@@ -11754,7 +11811,7 @@
     ac_need_defaults=false;;
 
   # This is an error.
-  -*) { { echo "$as_me:11757: error: unrecognized option: $1
+  -*) { { echo "$as_me:11814: error: unrecognized option: $1
 Try \`$0 --help' for more information." >&5
 echo "$as_me: error: unrecognized option: $1
 Try \`$0 --help' for more information." >&2;}
@@ -11825,7 +11882,7 @@
   "Makefile" ) CONFIG_FILES="$CONFIG_FILES Makefile" ;;
   "default" ) CONFIG_COMMANDS="$CONFIG_COMMANDS default" ;;
   "include/ncurses_cfg.h" ) CONFIG_HEADERS="$CONFIG_HEADERS include/ncurses_cfg.h:include/ncurses_cfg.hin" ;;
-  *) { { echo "$as_me:11828: error: invalid argument: $ac_config_target" >&5
+  *) { { echo "$as_me:11885: error: invalid argument: $ac_config_target" >&5
 echo "$as_me: error: invalid argument: $ac_config_target" >&2;}
    { (exit 1); exit 1; }; };;
   esac
@@ -12001,6 +12058,7 @@
 s,@cf_ada_make@,$cf_ada_make,;t t
 s,@cf_compile_generics@,$cf_compile_generics,;t t
 s,@cf_generic_objects@,$cf_generic_objects,;t t
+s,@USE_GNAT_SIGINT@,$USE_GNAT_SIGINT,;t t
 s,@PRAGMA_UNREF@,$PRAGMA_UNREF,;t t
 s,@USE_OLD_MAKERULES@,$USE_OLD_MAKERULES,;t t
 s,@USE_GNAT_PROJECTS@,$USE_GNAT_PROJECTS,;t t
@@ -12139,7 +12197,7 @@
   esac
 
   if test x"$ac_file" != x-; then
-    { echo "$as_me:12142: creating $ac_file" >&5
+    { echo "$as_me:12200: creating $ac_file" >&5
 echo "$as_me: creating $ac_file" >&6;}
     rm -f "$ac_file"
   fi
@@ -12157,7 +12215,7 @@
       -) echo $tmp/stdin ;;
       [\\/$]*)
          # Absolute (can't be DOS-style, as IFS=:)
-         test -f "$f" || { { echo "$as_me:12160: error: cannot find input file: $f" >&5
+         test -f "$f" || { { echo "$as_me:12218: error: cannot find input file: $f" >&5
 echo "$as_me: error: cannot find input file: $f" >&2;}
    { (exit 1); exit 1; }; }
          echo $f;;
@@ -12170,7 +12228,7 @@
            echo $srcdir/$f
          else
            # /dev/null tree
-           { { echo "$as_me:12173: error: cannot find input file: $f" >&5
+           { { echo "$as_me:12231: error: cannot find input file: $f" >&5
 echo "$as_me: error: cannot find input file: $f" >&2;}
    { (exit 1); exit 1; }; }
          fi;;
@@ -12236,7 +12294,7 @@
   * )   ac_file_in=$ac_file.in ;;
   esac
 
-  test x"$ac_file" != x- && { echo "$as_me:12239: creating $ac_file" >&5
+  test x"$ac_file" != x- && { echo "$as_me:12297: creating $ac_file" >&5
 echo "$as_me: creating $ac_file" >&6;}
 
   # First look for the input files in the build tree, otherwise in the
@@ -12247,7 +12305,7 @@
       -) echo $tmp/stdin ;;
       [\\/$]*)
          # Absolute (can't be DOS-style, as IFS=:)
-         test -f "$f" || { { echo "$as_me:12250: error: cannot find input file: $f" >&5
+         test -f "$f" || { { echo "$as_me:12308: error: cannot find input file: $f" >&5
 echo "$as_me: error: cannot find input file: $f" >&2;}
    { (exit 1); exit 1; }; }
          echo $f;;
@@ -12260,7 +12318,7 @@
            echo $srcdir/$f
          else
            # /dev/null tree
-           { { echo "$as_me:12263: error: cannot find input file: $f" >&5
+           { { echo "$as_me:12321: error: cannot find input file: $f" >&5
 echo "$as_me: error: cannot find input file: $f" >&2;}
    { (exit 1); exit 1; }; }
          fi;;
@@ -12318,7 +12376,7 @@
   rm -f $tmp/in
   if test x"$ac_file" != x-; then
     if cmp -s $ac_file $tmp/config.h 2>/dev/null; then
-      { echo "$as_me:12321: $ac_file is unchanged" >&5
+      { echo "$as_me:12379: $ac_file is unchanged" >&5
 echo "$as_me: $ac_file is unchanged" >&6;}
     else
       ac_dir=`$as_expr X"$ac_file" : 'X\(.*[^/]\)//*[^/][^/]*/*$' \| \
Index: Ada95/configure.in
Prereq:  1.26 
--- ncurses-5.8-20110326+/Ada95/configure.in	2011-03-26 23:54:05.000000000 +0000
+++ ncurses-5.8-20110329/Ada95/configure.in	2011-03-27 23:14:55.000000000 +0000
@@ -28,14 +28,14 @@
 dnl
 dnl Author: Thomas E. Dickey
 dnl
-dnl $Id: configure.in,v 1.26 2011/03/26 23:54:05 tom Exp $
+dnl $Id: configure.in,v 1.27 2011/03/27 23:14:55 tom Exp $
 dnl Process this file with autoconf to produce a configure script.
 dnl
 dnl See http://invisible-island.net/autoconf/ for additional information.
 dnl
 dnl ---------------------------------------------------------------------------
 AC_PREREQ(2.13.20020210)
-AC_REVISION($Revision: 1.26 $)
+AC_REVISION($Revision: 1.27 $)
 AC_INIT(gen/gen.c)
 AC_CONFIG_HEADER(include/ncurses_cfg.h:include/ncurses_cfg.hin)
 
@@ -76,7 +76,7 @@
 # if we find pkg-config, check if we should install the ".pc" files.
 CF_PKG_CONFIG
 
-if test "$PKG_CONFIG" != no ; then
+if test "$PKG_CONFIG" != none ; then
 	AC_MSG_CHECKING(if we should install .pc files for $PKG_CONFIG)
 
 	# Leave this as something that can be overridden in the environment.
@@ -508,6 +508,7 @@
 		esac
 
 		CF_GNAT_GENERICS
+		CF_GNAT_SIGINT
 		CF_GNAT_PRAGMA_UNREF
 		CF_GNAT_PROJECTS
 
Index: Ada95/samples/Makefile.in
Prereq:  1.44 
--- ncurses-5.8-20110326+/Ada95/samples/Makefile.in	2011-03-26 22:59:04.000000000 +0000
+++ ncurses-5.8-20110329/Ada95/samples/Makefile.in	2011-03-28 23:45:08.000000000 +0000
@@ -28,7 +28,7 @@
 #
 #  Author:  Juergen Pfeifer, 1996
 #
-#  $Id: Makefile.in,v 1.44 2011/03/26 22:59:04 tom Exp $
+#  $Id: Makefile.in,v 1.46 2011/03/28 23:45:08 tom Exp $
 #
 .SUFFIXES:
 
@@ -97,9 +97,9 @@
 ABASE        = $(ALIB)-curses
 
 CARGS        =-cargs $(ADAFLAGS)
-LARGS        =-largs @TEST_ARG2@ $(LD_FLAGS) -L../lib -lAdaCurses @TEST_LIBS2@
+LARGS        =-largs -L../lib -lAdaCurses @TEST_ARG2@ $(LD_FLAGS) @TEST_LIBS2@
 
-PROGS        = tour$x rain$x ncurses$x
+PROGS        = tour$x ncurses$x @USE_GNAT_SIGINT@ rain$x 
 
 all ::  $(PROGS)
 	@echo made $@
Index: Ada95/src/Makefile.in
Prereq:  1.58 
--- ncurses-5.8-20110326+/Ada95/src/Makefile.in	2011-03-27 00:14:06.000000000 +0000
+++ ncurses-5.8-20110329/Ada95/src/Makefile.in	2011-03-27 20:50:48.000000000 +0000
@@ -28,7 +28,7 @@
 #
 #  Author:  Juergen Pfeifer, 1996
 #
-#  $Id: Makefile.in,v 1.58 2011/03/27 00:14:06 tom Exp $
+#  $Id: Makefile.in,v 1.59 2011/03/27 20:50:48 tom Exp $
 #
 .SUFFIXES:
 
@@ -218,11 +218,14 @@
 	$(ADAPREP) -DADA_TRACE=@ADA_TRACE@ -DPRAGMA_UNREF=@PRAGMA_UNREF@ $(srcdir)/$(ABASE)-trace.adb_p $@
 
 ###############################################################################
-C_OBJS	= c_varargs_to_ada.o
+C_OBJS	= c_varargs_to_ada.o ncurses_compat.o
 
 c_varargs_to_ada.o :	$(srcdir)/c_varargs_to_ada.c
 	$(CC) $(CFLAGS_DEFAULT) -c -o $@ $(srcdir)/c_varargs_to_ada.c
 
+ncurses_compat.o :	$(srcdir)/ncurses_compat.c
+	$(CC) $(CFLAGS_DEFAULT) -c -o $@ $(srcdir)/ncurses_compat.c
+
 ###############################################################################
 
 MIXED_OBJS = $(C_OBJS) @USE_OLD_MAKERULES@$(LIBOBJS) @cf_generic_objects@
Index: Ada95/src/ncurses_compat.c
--- /dev/null	2011-03-29 08:03:39.515938487 +0000
+++ ncurses-5.8-20110329/Ada95/src/ncurses_compat.c	2011-03-28 00:29:04.000000000 +0000
@@ -0,0 +1,135 @@
+/****************************************************************************
+ * Copyright (c) 2011 Free Software Foundation, Inc.                        *
+ *                                                                          *
+ * Permission is hereby granted, free of charge, to any person obtaining a  *
+ * copy of this software and associated documentation files (the            *
+ * "Software"), to deal in the Software without restriction, including      *
+ * without limitation the rights to use, copy, modify, merge, publish,      *
+ * distribute, distribute with modifications, sublicense, and/or sell       *
+ * copies of the Software, and to permit persons to whom the Software is    *
+ * furnished to do so, subject to the following conditions:                 *
+ *                                                                          *
+ * The above copyright notice and this permission notice shall be included  *
+ * in all copies or substantial portions of the Software.                   *
+ *                                                                          *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS  *
+ * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF               *
+ * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.   *
+ * IN NO EVENT SHALL THE ABOVE COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,   *
+ * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR    *
+ * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR    *
+ * THE USE OR OTHER DEALINGS IN THE SOFTWARE.                               *
+ *                                                                          *
+ * Except as contained in this notice, the name(s) of the above copyright   *
+ * holders shall not be used in advertising or otherwise to promote the     *
+ * sale, use or other dealings in this Software without prior written       *
+ * authorization.                                                           *
+ ****************************************************************************/
+
+/****************************************************************************
+ *   Author:  Thomas E. Dickey, 2011                                        *
+ ****************************************************************************/
+
+/*
+    Version Control
+    $Id: ncurses_compat.c,v 1.2 2011/03/28 00:29:04 tom Exp $
+  --------------------------------------------------------------------------*/
+
+/*
+ * Provide compatibility with older versions of ncurses.
+ */
+#include <curses.h>
+
+#if defined(NCURSES_VERSION_PATCH)
+
+#if NCURSES_VERSION_PATCH < 20081122
+extern bool has_mouse(void);
+extern int _nc_has_mouse(void);
+
+bool
+has_mouse(void)
+{
+  return (bool) _nc_has_mouse();
+}
+#endif
+
+/*
+ * These are provided by lib_gen.c:
+ */
+#if NCURSES_VERSION_PATCH < 20070331
+extern bool (is_keypad) (const WINDOW *);
+extern bool (is_scrollok) (const WINDOW *);
+
+bool
+is_keypad(const WINDOW *win)
+{
+  return ((win)->_use_keypad);
+}
+
+bool
+  (is_scrollok) (const WINDOW *win)
+{
+  return ((win)->_scroll);
+}
+#endif
+
+#if NCURSES_VERSION_PATCH < 20060107
+extern int (getbegx) (WINDOW *);
+extern int (getbegy) (WINDOW *);
+extern int (getcurx) (WINDOW *);
+extern int (getcury) (WINDOW *);
+extern int (getmaxx) (WINDOW *);
+extern int (getmaxy) (WINDOW *);
+extern int (getparx) (WINDOW *);
+extern int (getpary) (WINDOW *);
+
+int
+  (getbegy) (WINDOW *win)
+{
+  return ((win) ? (win)->_begy : ERR);
+}
+
+int
+  (getbegx) (WINDOW *win)
+{
+  return ((win) ? (win)->_begx : ERR);
+}
+
+int
+  (getcury) (WINDOW *win)
+{
+  return ((win) ? (win)->_cury : ERR);
+}
+
+int
+  (getcurx) (WINDOW *win)
+{
+  return ((win) ? (win)->_curx : ERR);
+}
+
+int
+  (getmaxy) (WINDOW *win)
+{
+  return ((win) ? ((win)->_maxy + 1) : ERR);
+}
+
+int
+  (getmaxx) (WINDOW *win)
+{
+  return ((win) ? ((win)->_maxx + 1) : ERR);
+}
+
+int
+  (getpary) (WINDOW *win)
+{
+  return ((win) ? (win)->_pary : ERR);
+}
+
+int
+  (getparx) (WINDOW *win)
+{
+  return ((win) ? (win)->_parx : ERR);
+}
+#endif
+
+#endif
Index: NEWS
Prereq:  1.1673 
--- ncurses-5.8-20110326+/NEWS	2011-03-26 23:57:13.000000000 +0000
+++ ncurses-5.8-20110329/NEWS	2011-03-29 09:42:32.000000000 +0000
@@ -25,7 +25,7 @@
 -- sale, use or other dealings in this Software without prior written        --
 -- authorization.                                                            --
 -------------------------------------------------------------------------------
--- $Id: NEWS,v 1.1673 2011/03/26 23:57:13 tom Exp $
+-- $Id: NEWS,v 1.1676 2011/03/29 09:42:32 tom Exp $
 -------------------------------------------------------------------------------
 
 This is a log of changes that ncurses has gone through since Zeyd started
@@ -45,6 +45,17 @@
 Changes through 1.9.9e did not credit all contributions;
 it is not possible to add this information.
 
+20110329
+	> portability fixes for Ada95 binding:
+	+ add configure check to ensure that SIGINT works with gnat.  This is
+	  needed for the "rain" sample program.  If SIGINT does not work, omit
+	  that sample program.
+	+ correct typo in check of $PKG_CONFIG variable in Ada95/configure
+	+ add ncurses_compat.c, to supply functions used in the Ada95 binding
+	  which were added in 5.7 and later.
+	+ modify sed expression in CF_NCURSES_ADDON to eliminate a dependency
+	  upon GNU sed.
+
 20110326
 	+ add special check in Ada95/configure script for ncurses6 reentrant
 	  code.
Index: TO-DO
Prereq:  1.56 
--- ncurses-5.8-20110326+/TO-DO	2011-02-26 16:58:53.000000000 +0000
+++ ncurses-5.8-20110329/TO-DO	2011-03-28 00:23:02.000000000 +0000
@@ -25,7 +25,7 @@
 -- sale, use or other dealings in this Software without prior written        --
 -- authorization.                                                            --
 -------------------------------------------------------------------------------
--- $Id: TO-DO,v 1.56 2011/02/26 16:58:53 tom Exp $
+-- $Id: TO-DO,v 1.57 2011/03/28 00:23:02 tom Exp $
 -------------------------------------------------------------------------------
 
 SHORT-TERM TO-DO ITEMS:
@@ -66,24 +66,6 @@
 + the --with-pthread configuration builds for Cygwin, but does not work
   properly (test/worm.c shows all of the worms in the same location).
 
-+ the Ada95 tree may require a small fix to build on Cygwin, since the GNAT
-  port to that platform for 3.4.4 provides an incomplete Interrupts.Names
-  package.  For instance (your gcc version may be different):
-        /usr/lib/gcc/i686-pc-cygwin/3.4.4/adainclude/a-intnam.ads
-
-  cut here...
--------------------------------------------------------------------------------
---- a-intnam.ads.orig   2003-10-21 13:41:51.000000000 +0000
-+++ a-intnam.ads        2007-05-05 22:40:02.609375000 +0000
-@@ -44,5 +44,6 @@
-
-    DUMMY_INTERRUPT_1 : constant Interrupt_ID := 1;
-    DUMMY_INTERRUPT_2 : constant Interrupt_ID := 2;
-+   SIGINT : constant Interrupt_ID := 2;
-
- end Ada.Interrupts.Names;
--------------------------------------------------------------------------------
-
 + the --enable-rpath configure option builds for the corresponding platforms;
   however combining it with --with-ticlib and --with-termlib does not always
   produce libraries that can be run without setting environment variables.
Index: aclocal.m4
Prereq:  1.551 
--- ncurses-5.8-20110326+/aclocal.m4	2011-03-24 00:35:20.000000000 +0000
+++ ncurses-5.8-20110329/aclocal.m4	2011-03-28 00:21:01.000000000 +0000
@@ -28,7 +28,7 @@
 dnl
 dnl Author: Thomas E. Dickey 1995-on
 dnl
-dnl $Id: aclocal.m4,v 1.551 2011/03/24 00:35:20 tom Exp $
+dnl $Id: aclocal.m4,v 1.552 2011/03/28 00:21:01 tom Exp $
 dnl Macros used in NCURSES auto-configuration script.
 dnl
 dnl These macros are maintained separately from NCURSES.  The copyright on
@@ -1935,6 +1935,53 @@
 AC_SUBST(USE_GNAT_LIBRARIES)
 ])dnl
 dnl ---------------------------------------------------------------------------
+dnl CF_GNAT_SIGINT version: 1 updated: 2011/03/27 20:07:59
+dnl --------------
+dnl Check if gnat supports SIGINT, and presumably tasking.  For the latter, it
+dnl is noted that gnat may compile a tasking unit even for configurations which
+dnl fail at runtime.
+AC_DEFUN([CF_GNAT_SIGINT],[
+AC_CACHE_CHECK(if GNAT supports SIGINT,cf_cv_gnat_sigint,[
+CF_GNAT_TRY_LINK([with Ada.Interrupts.Names;
+
+package ConfTest is
+
+   pragma Warnings (Off);  --  the next pragma exists since 3.11p
+   pragma Unreserve_All_Interrupts;
+   pragma Warnings (On);
+
+   protected Process is
+      procedure Stop;
+      function Continue return Boolean;
+      pragma Attach_Handler (Stop, Ada.Interrupts.Names.SIGINT);
+   private
+      Done : Boolean := False;
+   end Process;
+
+end ConfTest;],
+[package body ConfTest is
+   protected body Process is
+      procedure Stop is
+      begin
+         Done := True;
+      end Stop;
+      function Continue return Boolean is
+      begin
+         return not Done;
+      end Continue;
+   end Process;
+end ConfTest;],
+	[cf_cv_gnat_sigint=yes],
+	[cf_cv_gnat_sigint=no])])
+
+if test $cf_cv_gnat_sigint = yes ; then
+	USE_GNAT_SIGINT=""
+else
+	USE_GNAT_SIGINT="#"
+fi
+AC_SUBST(USE_GNAT_SIGINT)
+])dnl
+dnl ---------------------------------------------------------------------------
 dnl CF_GNAT_TRY_LINK version: 3 updated: 2011/03/19 14:47:45
 dnl ----------------
 dnl Verify that a test program compiles/links with GNAT.
Index: configure
--- ncurses-5.8-20110326+/configure	2011-03-24 08:27:00.000000000 +0000
+++ ncurses-5.8-20110329/configure	2011-03-28 00:24:09.000000000 +0000
@@ -1,5 +1,5 @@
 #! /bin/sh
-# From configure.in Revision: 1.519 .
+# From configure.in Revision: 1.520 .
 # Guess values for system-dependent variables and create Makefiles.
 # Generated by Autoconf 2.52.20101002.
 #
@@ -18197,7 +18197,64 @@
 	cf_generic_objects=
 fi
 
-echo "$as_me:18200: checking if GNAT pragma Unreferenced works" >&5
+echo "$as_me:18200: checking if GNAT supports SIGINT" >&5
+echo $ECHO_N "checking if GNAT supports SIGINT... $ECHO_C" >&6
+if test "${cf_cv_gnat_sigint+set}" = set; then
+  echo $ECHO_N "(cached) $ECHO_C" >&6
+else
+
+rm -rf conftest* *~conftest*
+cat >>conftest.ads <<CF_EOF
+with Ada.Interrupts.Names;
+
+package ConfTest is
+
+   pragma Warnings (Off);  --  the next pragma exists since 3.11p
+   pragma Unreserve_All_Interrupts;
+   pragma Warnings (On);
+
+   protected Process is
+      procedure Stop;
+      function Continue return Boolean;
+      pragma Attach_Handler (Stop, Ada.Interrupts.Names.SIGINT);
+   private
+      Done : Boolean := False;
+   end Process;
+
+end ConfTest;
+CF_EOF
+cat >>conftest.adb <<CF_EOF
+package body ConfTest is
+   protected body Process is
+      procedure Stop is
+      begin
+         Done := True;
+      end Stop;
+      function Continue return Boolean is
+      begin
+         return not Done;
+      end Continue;
+   end Process;
+end ConfTest;
+CF_EOF
+if ( $cf_ada_make $ADAFLAGS conftest 1>&5 2>&1 ) ; then
+      cf_cv_gnat_sigint=yes
+else
+   cf_cv_gnat_sigint=no
+fi
+rm -rf conftest* *~conftest*
+
+fi
+echo "$as_me:18248: result: $cf_cv_gnat_sigint" >&5
+echo "${ECHO_T}$cf_cv_gnat_sigint" >&6
+
+if test $cf_cv_gnat_sigint = yes ; then
+	USE_GNAT_SIGINT=""
+else
+	USE_GNAT_SIGINT="#"
+fi
+
+echo "$as_me:18257: checking if GNAT pragma Unreferenced works" >&5
 echo $ECHO_N "checking if GNAT pragma Unreferenced works... $ECHO_C" >&6
 if test "${cf_cv_pragma_unreferenced+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -18228,7 +18285,7 @@
 rm -rf conftest* *~conftest*
 
 fi
-echo "$as_me:18231: result: $cf_cv_pragma_unreferenced" >&5
+echo "$as_me:18288: result: $cf_cv_pragma_unreferenced" >&5
 echo "${ECHO_T}$cf_cv_pragma_unreferenced" >&6
 
 # if the pragma is supported, use it (needed in the Trace code).
@@ -18241,7 +18298,7 @@
 cf_gnat_libraries=no
 cf_gnat_projects=no
 
-echo "$as_me:18244: checking if GNAT supports project files" >&5
+echo "$as_me:18301: checking if GNAT supports project files" >&5
 echo $ECHO_N "checking if GNAT supports project files... $ECHO_C" >&6
 case $cf_gnat_version in #(vi
 3.[0-9]*) #(vi
@@ -18309,14 +18366,14 @@
 	esac
 	;;
 esac
-echo "$as_me:18312: result: $cf_gnat_projects" >&5
+echo "$as_me:18369: result: $cf_gnat_projects" >&5
 echo "${ECHO_T}$cf_gnat_projects" >&6
 
 if test $cf_gnat_projects = yes
 then
-	echo "$as_me:18317: checking if GNAT supports libraries" >&5
+	echo "$as_me:18374: checking if GNAT supports libraries" >&5
 echo $ECHO_N "checking if GNAT supports libraries... $ECHO_C" >&6
-	echo "$as_me:18319: result: $cf_gnat_libraries" >&5
+	echo "$as_me:18376: result: $cf_gnat_libraries" >&5
 echo "${ECHO_T}$cf_gnat_libraries" >&6
 fi
 
@@ -18336,7 +18393,7 @@
 	USE_GNAT_LIBRARIES="#"
 fi
 
-echo "$as_me:18339: checking for ada-compiler" >&5
+echo "$as_me:18396: checking for ada-compiler" >&5
 echo $ECHO_N "checking for ada-compiler... $ECHO_C" >&6
 
 # Check whether --with-ada-compiler or --without-ada-compiler was given.
@@ -18347,12 +18404,12 @@
   cf_ada_compiler=gnatmake
 fi;
 
-echo "$as_me:18350: result: $cf_ada_compiler" >&5
+echo "$as_me:18407: result: $cf_ada_compiler" >&5
 echo "${ECHO_T}$cf_ada_compiler" >&6
 
 			cf_ada_package=terminal_interface
 
-echo "$as_me:18355: checking for ada-include" >&5
+echo "$as_me:18412: checking for ada-include" >&5
 echo $ECHO_N "checking for ada-include... $ECHO_C" >&6
 
 # Check whether --with-ada-include or --without-ada-include was given.
@@ -18388,7 +18445,7 @@
   withval=`echo $withval | sed -e s%NONE%$cf_path_syntax%`
   ;;
 *)
-  { { echo "$as_me:18391: error: expected a pathname, not \"$withval\"" >&5
+  { { echo "$as_me:18448: error: expected a pathname, not \"$withval\"" >&5
 echo "$as_me: error: expected a pathname, not \"$withval\"" >&2;}
    { (exit 1); exit 1; }; }
   ;;
@@ -18397,10 +18454,10 @@
 fi
 ADA_INCLUDE="$withval"
 
-echo "$as_me:18400: result: $ADA_INCLUDE" >&5
+echo "$as_me:18457: result: $ADA_INCLUDE" >&5
 echo "${ECHO_T}$ADA_INCLUDE" >&6
 
-echo "$as_me:18403: checking for ada-objects" >&5
+echo "$as_me:18460: checking for ada-objects" >&5
 echo $ECHO_N "checking for ada-objects... $ECHO_C" >&6
 
 # Check whether --with-ada-objects or --without-ada-objects was given.
@@ -18436,7 +18493,7 @@
   withval=`echo $withval | sed -e s%NONE%$cf_path_syntax%`
   ;;
 *)
-  { { echo "$as_me:18439: error: expected a pathname, not \"$withval\"" >&5
+  { { echo "$as_me:18496: error: expected a pathname, not \"$withval\"" >&5
 echo "$as_me: error: expected a pathname, not \"$withval\"" >&2;}
    { (exit 1); exit 1; }; }
   ;;
@@ -18445,10 +18502,10 @@
 fi
 ADA_OBJECTS="$withval"
 
-echo "$as_me:18448: result: $ADA_OBJECTS" >&5
+echo "$as_me:18505: result: $ADA_OBJECTS" >&5
 echo "${ECHO_T}$ADA_OBJECTS" >&6
 
-echo "$as_me:18451: checking if an Ada95 shared-library should be built" >&5
+echo "$as_me:18508: checking if an Ada95 shared-library should be built" >&5
 echo $ECHO_N "checking if an Ada95 shared-library should be built... $ECHO_C" >&6
 
 # Check whether --with-ada-sharedlib or --without-ada-sharedlib was given.
@@ -18458,7 +18515,7 @@
 else
   with_ada_sharedlib=no
 fi;
-echo "$as_me:18461: result: $with_ada_sharedlib" >&5
+echo "$as_me:18518: result: $with_ada_sharedlib" >&5
 echo "${ECHO_T}$with_ada_sharedlib" >&6
 
 ADA_SHAREDLIB='lib$(LIB_NAME).so.1'
@@ -18489,7 +18546,7 @@
 ### chooses to split module lists into libraries.
 ###
 ### (see CF_LIB_RULES).
-echo "$as_me:18492: checking for library subsets" >&5
+echo "$as_me:18549: checking for library subsets" >&5
 echo $ECHO_N "checking for library subsets... $ECHO_C" >&6
 LIB_SUBSETS=
 
@@ -18530,7 +18587,7 @@
 test "$with_widec"     = yes && LIB_SUBSETS="${LIB_SUBSETS}+widechar"
 test "$with_ext_funcs" = yes && LIB_SUBSETS="${LIB_SUBSETS}+ext_funcs"
 
-echo "$as_me:18533: result: $LIB_SUBSETS" >&5
+echo "$as_me:18590: result: $LIB_SUBSETS" >&5
 echo "${ECHO_T}$LIB_SUBSETS" >&6
 
 ### Construct the list of include-directories to be generated
@@ -18568,7 +18625,7 @@
 fi
 
 ### Build up pieces for makefile rules
-echo "$as_me:18571: checking default library suffix" >&5
+echo "$as_me:18628: checking default library suffix" >&5
 echo $ECHO_N "checking default library suffix... $ECHO_C" >&6
 
 	case $DFT_LWR_MODEL in
@@ -18579,10 +18636,10 @@
 	shared)  DFT_ARG_SUFFIX=''   ;;
 	esac
 	test -n "$LIB_SUFFIX" && DFT_ARG_SUFFIX="${LIB_SUFFIX}${DFT_ARG_SUFFIX}"
-echo "$as_me:18582: result: $DFT_ARG_SUFFIX" >&5
+echo "$as_me:18639: result: $DFT_ARG_SUFFIX" >&5
 echo "${ECHO_T}$DFT_ARG_SUFFIX" >&6
 
-echo "$as_me:18585: checking default library-dependency suffix" >&5
+echo "$as_me:18642: checking default library-dependency suffix" >&5
 echo $ECHO_N "checking default library-dependency suffix... $ECHO_C" >&6
 
 	case $DFT_LWR_MODEL in #(vi
@@ -18635,10 +18692,10 @@
 	esac
 	test -n "$LIB_SUFFIX" && DFT_LIB_SUFFIX="${LIB_SUFFIX}${DFT_LIB_SUFFIX}"
 	test -n "$LIB_SUFFIX" && DFT_DEP_SUFFIX="${LIB_SUFFIX}${DFT_DEP_SUFFIX}"
-echo "$as_me:18638: result: $DFT_DEP_SUFFIX" >&5
+echo "$as_me:18695: result: $DFT_DEP_SUFFIX" >&5
 echo "${ECHO_T}$DFT_DEP_SUFFIX" >&6
 
-echo "$as_me:18641: checking default object directory" >&5
+echo "$as_me:18698: checking default object directory" >&5
 echo $ECHO_N "checking default object directory... $ECHO_C" >&6
 
 	case $DFT_LWR_MODEL in
@@ -18654,12 +18711,12 @@
 			DFT_OBJ_SUBDIR='obj_s' ;;
 		esac
 	esac
-echo "$as_me:18657: result: $DFT_OBJ_SUBDIR" >&5
+echo "$as_me:18714: result: $DFT_OBJ_SUBDIR" >&5
 echo "${ECHO_T}$DFT_OBJ_SUBDIR" >&6
 
 # libtool thinks it can make c++ shared libraries (perhaps only g++)
 if test "$cf_with_cxx" = yes ; then
-echo "$as_me:18662: checking c++ library-dependency suffix" >&5
+echo "$as_me:18719: checking c++ library-dependency suffix" >&5
 echo $ECHO_N "checking c++ library-dependency suffix... $ECHO_C" >&6
 if test "$with_libtool" != "no"; then
 	CXX_LIB_SUFFIX=$DFT_DEP_SUFFIX
@@ -18716,7 +18773,7 @@
 	test -n "$LIB_SUFFIX" && CXX_LIB_SUFFIX="${LIB_SUFFIX}${CXX_LIB_SUFFIX}"
 	test -n "$LIB_SUFFIX" && CXX_DEP_SUFFIX="${LIB_SUFFIX}${CXX_DEP_SUFFIX}"
 fi
-echo "$as_me:18719: result: $CXX_LIB_SUFFIX" >&5
+echo "$as_me:18776: result: $CXX_LIB_SUFFIX" >&5
 echo "${ECHO_T}$CXX_LIB_SUFFIX" >&6
 
 fi
@@ -18870,19 +18927,19 @@
 
 if test -n "$LDFLAGS_STATIC" && test -n "$LDFLAGS_SHARED"
 then
-	echo "$as_me:18873: checking if linker supports switching between static/dynamic" >&5
+	echo "$as_me:18930: checking if linker supports switching between static/dynamic" >&5
 echo $ECHO_N "checking if linker supports switching between static/dynamic... $ECHO_C" >&6
 
 	rm -f libconftest.a
 	cat >conftest.$ac_ext <<EOF
-#line 18878 "configure"
+#line 18935 "configure"
 #include <stdio.h>
 int cf_ldflags_static(FILE *fp) { return fflush(fp); }
 EOF
-	if { (eval echo "$as_me:18882: \"$ac_compile\"") >&5
+	if { (eval echo "$as_me:18939: \"$ac_compile\"") >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
-  echo "$as_me:18885: \$? = $ac_status" >&5
+  echo "$as_me:18942: \$? = $ac_status" >&5
   (exit $ac_status); } ; then
 		( $AR $ARFLAGS libconftest.a conftest.o ) 2>&5 1>/dev/null
 		( eval $RANLIB libconftest.a ) 2>&5 >/dev/null
@@ -18893,10 +18950,10 @@
 
 	LIBS="$LDFLAGS_STATIC -L`pwd` -lconftest $LDFLAGS_DYNAMIC $LIBS"
 	cat >conftest.$ac_ext <<_ACEOF
-#line 18896 "configure"
+#line 18953 "configure"
 #include "confdefs.h"
 
-#line 18899 "configure"
+#line 18956 "configure"
 #include <stdio.h>
 int cf_ldflags_static(FILE *fp);
 
@@ -18911,16 +18968,16 @@
 }
 _ACEOF
 rm -f conftest.$ac_objext conftest$ac_exeext
-if { (eval echo "$as_me:18914: \"$ac_link\"") >&5
+if { (eval echo "$as_me:18971: \"$ac_link\"") >&5
   (eval $ac_link) 2>&5
   ac_status=$?
-  echo "$as_me:18917: \$? = $ac_status" >&5
+  echo "$as_me:18974: \$? = $ac_status" >&5
   (exit $ac_status); } &&
          { ac_try='test -s conftest$ac_exeext'
-  { (eval echo "$as_me:18920: \"$ac_try\"") >&5
+  { (eval echo "$as_me:18977: \"$ac_try\"") >&5
   (eval $ac_try) 2>&5
   ac_status=$?
-  echo "$as_me:18923: \$? = $ac_status" >&5
+  echo "$as_me:18980: \$? = $ac_status" >&5
   (exit $ac_status); }; }; then
   cf_ldflags_static=yes
 else
@@ -18933,7 +18990,7 @@
 	rm -f libconftest.*
 	LIBS="$cf_save_LIBS"
 
-	echo "$as_me:18936: result: $cf_ldflags_static" >&5
+	echo "$as_me:18993: result: $cf_ldflags_static" >&5
 echo "${ECHO_T}$cf_ldflags_static" >&6
 
 	if test $cf_ldflags_static != yes
@@ -18949,12 +19006,12 @@
 	;;
 esac
 
-echo "$as_me:18952: checking where we will install curses.h" >&5
+echo "$as_me:19009: checking where we will install curses.h" >&5
 echo $ECHO_N "checking where we will install curses.h... $ECHO_C" >&6
 test "$with_overwrite" = no && \
 test "x$includedir" = 'x${prefix}/include' && \
 	includedir='${prefix}/include/ncurses'${LIB_SUFFIX}
-echo "$as_me:18957: result: $includedir" >&5
+echo "$as_me:19014: result: $includedir" >&5
 echo "${ECHO_T}$includedir" >&6
 
 ### Resolve a conflict between normal and wide-curses by forcing applications
@@ -18962,7 +19019,7 @@
 if test "$with_overwrite" != no ; then
 if test "$NCURSES_LIBUTF8" = 1 ; then
 	NCURSES_LIBUTF8='defined(HAVE_LIBUTF8_H)'
-	{ echo "$as_me:18965: WARNING: Wide-character applications must define HAVE_LIBUTF8_H to include curses.h" >&5
+	{ echo "$as_me:19022: WARNING: Wide-character applications must define HAVE_LIBUTF8_H to include curses.h" >&5
 echo "$as_me: WARNING: Wide-character applications must define HAVE_LIBUTF8_H to include curses.h" >&2;}
 fi
 fi
@@ -18979,7 +19036,7 @@
 ### Construct the list of subdirectories for which we'll customize makefiles
 ### with the appropriate compile-rules.
 
-echo "$as_me:18982: checking for src modules" >&5
+echo "$as_me:19039: checking for src modules" >&5
 echo $ECHO_N "checking for src modules... $ECHO_C" >&6
 
 # dependencies and linker-arguments for test-programs
@@ -19042,7 +19099,7 @@
 		fi
 	fi
 done
-echo "$as_me:19045: result: $cf_cv_src_modules" >&5
+echo "$as_me:19102: result: $cf_cv_src_modules" >&5
 echo "${ECHO_T}$cf_cv_src_modules" >&6
 
 TEST_ARGS="-L${LIB_DIR} $TEST_ARGS"
@@ -19248,7 +19305,7 @@
 
 # Extract the first word of "tic", so it can be a program name with args.
 set dummy tic; ac_word=$2
-echo "$as_me:19251: checking for $ac_word" >&5
+echo "$as_me:19308: checking for $ac_word" >&5
 echo $ECHO_N "checking for $ac_word... $ECHO_C" >&6
 if test "${ac_cv_path_TIC_PATH+set}" = set; then
   echo $ECHO_N "(cached) $ECHO_C" >&6
@@ -19265,7 +19322,7 @@
   test -z "$ac_dir" && ac_dir=.
   if $as_executable_p "$ac_dir/$ac_word"; then
    ac_cv_path_TIC_PATH="$ac_dir/$ac_word"
-   echo "$as_me:19268: found $ac_dir/$ac_word" >&5
+   echo "$as_me:19325: found $ac_dir/$ac_word" >&5
    break
 fi
 done
@@ -19277,10 +19334,10 @@
 TIC_PATH=$ac_cv_path_TIC_PATH
 
 if test -n "$TIC_PATH"; then
-  echo "$as_me:19280: result: $TIC_PATH" >&5
+  echo "$as_me:19337: result: $TIC_PATH" >&5
 echo "${ECHO_T}$TIC_PATH" >&6
 else
-  echo "$as_me:19283: result: no" >&5
+  echo "$as_me:19340: result: no" >&5
 echo "${ECHO_T}no" >&6
 fi
 
@@ -19288,7 +19345,7 @@
 then
 	if test "$TIC_PATH" = unknown
 	then
-		{ echo "$as_me:19291: WARNING: no tic program found for fallbacks" >&5
+		{ echo "$as_me:19348: WARNING: no tic program found for fallbacks" >&5
 echo "$as_me: WARNING: no tic program found for fallbacks" >&2;}
 	fi
 fi
@@ -19389,7 +19446,7 @@
 : ${CONFIG_STATUS=./config.status}
 ac_clean_files_save=$ac_clean_files
 ac_clean_files="$ac_clean_files $CONFIG_STATUS"
-{ echo "$as_me:19392: creating $CONFIG_STATUS" >&5
+{ echo "$as_me:19449: creating $CONFIG_STATUS" >&5
 echo "$as_me: creating $CONFIG_STATUS" >&6;}
 cat >$CONFIG_STATUS <<_ACEOF
 #! $SHELL
@@ -19565,7 +19622,7 @@
     echo "$ac_cs_version"; exit 0 ;;
   --he | --h)
     # Conflict between --help and --header
-    { { echo "$as_me:19568: error: ambiguous option: $1
+    { { echo "$as_me:19625: error: ambiguous option: $1
 Try \`$0 --help' for more information." >&5
 echo "$as_me: error: ambiguous option: $1
 Try \`$0 --help' for more information." >&2;}
@@ -19584,7 +19641,7 @@
     ac_need_defaults=false;;
 
   # This is an error.
-  -*) { { echo "$as_me:19587: error: unrecognized option: $1
+  -*) { { echo "$as_me:19644: error: unrecognized option: $1
 Try \`$0 --help' for more information." >&5
 echo "$as_me: error: unrecognized option: $1
 Try \`$0 --help' for more information." >&2;}
@@ -19690,7 +19747,7 @@
   "Makefile" ) CONFIG_FILES="$CONFIG_FILES Makefile" ;;
   "default" ) CONFIG_COMMANDS="$CONFIG_COMMANDS default" ;;
   "include/ncurses_cfg.h" ) CONFIG_HEADERS="$CONFIG_HEADERS include/ncurses_cfg.h:include/ncurses_cfg.hin" ;;
-  *) { { echo "$as_me:19693: error: invalid argument: $ac_config_target" >&5
+  *) { { echo "$as_me:19750: error: invalid argument: $ac_config_target" >&5
 echo "$as_me: error: invalid argument: $ac_config_target" >&2;}
    { (exit 1); exit 1; }; };;
   esac
@@ -19939,6 +19996,7 @@
 s,@cf_ada_make@,$cf_ada_make,;t t
 s,@cf_compile_generics@,$cf_compile_generics,;t t
 s,@cf_generic_objects@,$cf_generic_objects,;t t
+s,@USE_GNAT_SIGINT@,$USE_GNAT_SIGINT,;t t
 s,@PRAGMA_UNREF@,$PRAGMA_UNREF,;t t
 s,@USE_OLD_MAKERULES@,$USE_OLD_MAKERULES,;t t
 s,@USE_GNAT_PROJECTS@,$USE_GNAT_PROJECTS,;t t
@@ -20099,7 +20157,7 @@
   esac
 
   if test x"$ac_file" != x-; then
-    { echo "$as_me:20102: creating $ac_file" >&5
+    { echo "$as_me:20160: creating $ac_file" >&5
 echo "$as_me: creating $ac_file" >&6;}
     rm -f "$ac_file"
   fi
@@ -20117,7 +20175,7 @@
       -) echo $tmp/stdin ;;
       [\\/$]*)
          # Absolute (can't be DOS-style, as IFS=:)
-         test -f "$f" || { { echo "$as_me:20120: error: cannot find input file: $f" >&5
+         test -f "$f" || { { echo "$as_me:20178: error: cannot find input file: $f" >&5
 echo "$as_me: error: cannot find input file: $f" >&2;}
    { (exit 1); exit 1; }; }
          echo $f;;
@@ -20130,7 +20188,7 @@
            echo $srcdir/$f
          else
            # /dev/null tree
-           { { echo "$as_me:20133: error: cannot find input file: $f" >&5
+           { { echo "$as_me:20191: error: cannot find input file: $f" >&5
 echo "$as_me: error: cannot find input file: $f" >&2;}
    { (exit 1); exit 1; }; }
          fi;;
@@ -20196,7 +20254,7 @@
   * )   ac_file_in=$ac_file.in ;;
   esac
 
-  test x"$ac_file" != x- && { echo "$as_me:20199: creating $ac_file" >&5
+  test x"$ac_file" != x- && { echo "$as_me:20257: creating $ac_file" >&5
 echo "$as_me: creating $ac_file" >&6;}
 
   # First look for the input files in the build tree, otherwise in the
@@ -20207,7 +20265,7 @@
       -) echo $tmp/stdin ;;
       [\\/$]*)
          # Absolute (can't be DOS-style, as IFS=:)
-         test -f "$f" || { { echo "$as_me:20210: error: cannot find input file: $f" >&5
+         test -f "$f" || { { echo "$as_me:20268: error: cannot find input file: $f" >&5
 echo "$as_me: error: cannot find input file: $f" >&2;}
    { (exit 1); exit 1; }; }
          echo $f;;
@@ -20220,7 +20278,7 @@
            echo $srcdir/$f
          else
            # /dev/null tree
-           { { echo "$as_me:20223: error: cannot find input file: $f" >&5
+           { { echo "$as_me:20281: error: cannot find input file: $f" >&5
 echo "$as_me: error: cannot find input file: $f" >&2;}
    { (exit 1); exit 1; }; }
          fi;;
@@ -20278,7 +20336,7 @@
   rm -f $tmp/in
   if test x"$ac_file" != x-; then
     if cmp -s $ac_file $tmp/config.h 2>/dev/null; then
-      { echo "$as_me:20281: $ac_file is unchanged" >&5
+      { echo "$as_me:20339: $ac_file is unchanged" >&5
 echo "$as_me: $ac_file is unchanged" >&6;}
     else
       ac_dir=`$as_expr X"$ac_file" : 'X\(.*[^/]\)//*[^/][^/]*/*$' \| \
Index: configure.in
Prereq:  1.519 
--- ncurses-5.8-20110326+/configure.in	2011-03-24 00:36:08.000000000 +0000
+++ ncurses-5.8-20110329/configure.in	2011-03-28 00:22:26.000000000 +0000
@@ -28,14 +28,14 @@
 dnl
 dnl Author: Thomas E. Dickey 1995-on
 dnl
-dnl $Id: configure.in,v 1.519 2011/03/24 00:36:08 tom Exp $
+dnl $Id: configure.in,v 1.520 2011/03/28 00:22:26 tom Exp $
 dnl Process this file with autoconf to produce a configure script.
 dnl
 dnl See http://invisible-island.net/autoconf/ for additional information.
 dnl
 dnl ---------------------------------------------------------------------------
 AC_PREREQ(2.13.20020210)
-AC_REVISION($Revision: 1.519 $)
+AC_REVISION($Revision: 1.520 $)
 AC_INIT(ncurses/base/lib_initscr.c)
 AC_CONFIG_HEADER(include/ncurses_cfg.h:include/ncurses_cfg.hin)
 
@@ -1609,6 +1609,7 @@
 			esac
 
 			CF_GNAT_GENERICS
+			CF_GNAT_SIGINT
 			CF_GNAT_PRAGMA_UNREF
 			CF_GNAT_PROJECTS
 
Index: dist.mk
Prereq:  1.805 
--- ncurses-5.8-20110326+/dist.mk	2011-03-22 09:01:34.000000000 +0000
+++ ncurses-5.8-20110329/dist.mk	2011-03-29 09:42:25.000000000 +0000
@@ -25,7 +25,7 @@
 # use or other dealings in this Software without prior written               #
 # authorization.                                                             #
 ##############################################################################
-# $Id: dist.mk,v 1.805 2011/03/22 09:01:34 tom Exp $
+# $Id: dist.mk,v 1.807 2011/03/29 09:42:25 tom Exp $
 # Makefile for creating ncurses distributions.
 #
 # This only needs to be used directly as a makefile by developers, but
@@ -37,7 +37,7 @@
 # These define the major/minor/patch versions of ncurses.
 NCURSES_MAJOR = 5
 NCURSES_MINOR = 8
-NCURSES_PATCH = 20110326
+NCURSES_PATCH = 20110329
 
 # We don't append the patch to the version, since this only applies to releases
 VERSION = $(NCURSES_MAJOR).$(NCURSES_MINOR)
